resolve_schema_from_matchers

Function resolve_schema_from_matchers 

pub fn resolve_schema_from_matchers(
    matchers: &[Matcher],
) -> Result<Option<String>>
Resolves the optional schema selector shared by Prometheus query paths.

Like the PromQL planner, the last equality matcher selects the schema.